@@ -9,18 +9,39 @@ require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
 
 our @EXPORT = qw( );
+# More or less this same list is in Makefile.PL.  Should unify.
 our @EXPORT_OK = qw (usleep sleep ualarm alarm gettimeofday time tv_interval
 		 getitimer setitimer nanosleep clock_gettime clock_getres
 		 clock clock_nanosleep
-		 CLOCK_BOOTTIME CLOCK_HIGHRES
-		 CLOCK_MONOTONIC CLOCK_MONOTONIC_COARSE
-		 CLOCK_MONOTONIC_PRECISE CLOCK_MONOTONIC_RAW
+		 CLOCKS_PER_SEC
+		 CLOCK_BOOTTIME
+		 CLOCK_HIGHRES
+		 CLOCK_MONOTONIC
+		 CLOCK_MONOTONIC_COARSE
+		 CLOCK_MONOTONIC_FAST
+		 CLOCK_MONOTONIC_PRECISE
+		 CLOCK_MONOTONIC_RAW
 		 CLOCK_PROCESS_CPUTIME_ID
-		 CLOCK_REALTIME CLOCK_REALTIME_COARSE
-		 CLOCK_REALTIME_FAST CLOCK_REALTIME_PRECISE
-		 CLOCK_SECOND CLOCK_SOFTTIME CLOCK_THREAD_CPUTIME_ID
-		 CLOCK_TIMEOFDAY CLOCKS_PER_SEC
-		 ITIMER_REAL ITIMER_VIRTUAL ITIMER_PROF ITIMER_REALPROF
+		 CLOCK_PROF
+		 CLOCK_REALTIME
+		 CLOCK_REALTIME_COARSE
+		 CLOCK_REALTIME_FAST
+		 CLOCK_REALTIME_PRECISE
+		 CLOCK_REALTIME_RAW
+		 CLOCK_SECOND
+		 CLOCK_SOFTTIME
+		 CLOCK_THREAD_CPUTIME_ID
+		 CLOCK_TIMEOFDAY
+		 CLOCK_UPTIME
+		 CLOCK_UPTIME_COARSE
+		 CLOCK_UPTIME_FAST
+		 CLOCK_UPTIME_PRECISE
+		 CLOCK_UPTIME_RAW
+		 CLOCK_VIRTUAL
+		 ITIMER_PROF
+		 ITIMER_REAL
+		 ITIMER_REALPROF
+		 ITIMER_VIRTUAL
 		 TIMER_ABSTIME
 		 d_usleep d_ualarm d_gettimeofday d_getitimer d_setitimer
 		 d_nanosleep d_clock_gettime d_clock_getres d_hires_utime
@@ -28,7 +49,7 @@ our @EXPORT_OK = qw (usleep sleep ualarm alarm gettimeofday time tv_interval
 		 stat lstat utime
 		);
 
-our $VERSION = '1.9742';
+our $VERSION = '1.9744';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
